==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/RELIABILITYRANKINGDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour RELIABILITYRANKINGDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="RELIABILITYRANKINGDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGLOCKED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGINDEXCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGSCORE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OUTOFSYNC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SETUPLASTUPDATEDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SURVEYLASTUPDATEDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VALUESLASTCALCULATEDDATE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RELIABILITYRANKINGDETAILS_Type", propOrder = {
    "reliabilityrankinglocked",
    "reliabilityrankingindexcode",
    "reliabilityrankingid",
    "reliabilityrankingscore",
    "outofsync",
    "setuplastupdateddate",
    "surveylastupdateddate",
    "valueslastcalculateddate"
})
public class RELIABILITYRANKINGDETAILS_Type {

    @XmlElement(name = "RELIABILITYRANKINGLOCKED")
    protected String reliabilityrankinglocked;
    @XmlElement(name = "RELIABILITYRANKINGINDEXCODE")
    protected String reliabilityrankingindexcode;
    @XmlElement(name = "RELIABILITYRANKINGID")
    protected RELIABILITYRANKINGID_Type reliabilityrankingid;
    @XmlElement(name = "RELIABILITYRANKINGSCORE")
    protected QUANTITY reliabilityrankingscore;
    @XmlElement(name = "OUTOFSYNC")
    protected String outofsync;
    @XmlElement(name = "SETUPLASTUPDATEDDATE")
    protected DATETIME setuplastupdateddate;
    @XmlElement(name = "SURVEYLASTUPDATEDDATE")
    protected DATETIME surveylastupdateddate;
    @XmlElement(name = "VALUESLASTCALCULATEDDATE")
    protected DATETIME valueslastcalculateddate;

    /**
     * Obtient la valeur de la propriété reliabilityrankinglocked.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRELIABILITYRANKINGLOCKED() {
        return reliabilityrankinglocked;
    }

    /**
     * Définit la valeur de la propriété reliabilityrankinglocked.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRELIABILITYRANKINGLOCKED(String value) {
        this.reliabilityrankinglocked = value;
    }

    /**
     * Obtient la valeur de la propriété reliabilityrankingindexcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRELIABILITYRANKINGINDEXCODE() {
        return reliabilityrankingindexcode;
    }

    /**
     * Définit la valeur de la propriété reliabilityrankingindexcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRELIABILITYRANKINGINDEXCODE(String value) {
        this.reliabilityrankingindexcode = value;
    }

    /**
     * Obtient la valeur de la propriété reliabilityrankingid.
     * 
     * @return
     *     possible object is
     *     {@link RELIABILITYRANKINGID_Type }
     *     
     */
    public RELIABILITYRANKINGID_Type getRELIABILITYRANKINGID() {
        return reliabilityrankingid;
    }

    /**
     * Définit la valeur de la propriété reliabilityrankingid.
     * 
     * @param value
     *     allowed object is
     *     {@link RELIABILITYRANKINGID_Type }
     *     
     */
    public void setRELIABILITYRANKINGID(RELIABILITYRANKINGID_Type value) {
        this.reliabilityrankingid = value;
    }

    /**
     * Obtient la valeur de la propriété reliabilityrankingscore.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getRELIABILITYRANKINGSCORE() {
        return reliabilityrankingscore;
    }

    /**
     * Définit la valeur de la propriété reliabilityrankingscore.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setRELIABILITYRANKINGSCORE(QUANTITY value) {
        this.reliabilityrankingscore = value;
    }

    /**
     * Obtient la valeur de la propriété outofsync.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOUTOFSYNC() {
        return outofsync;
    }

    /**
     * Définit la valeur de la propriété outofsync.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOUTOFSYNC(String value) {
        this.outofsync = value;
    }

    /**
     * Obtient la valeur de la propriété setuplastupdateddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSETUPLASTUPDATEDDATE() {
        return setuplastupdateddate;
    }

    /**
     * Définit la valeur de la propriété setuplastupdateddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSETUPLASTUPDATEDDATE(DATETIME value) {
        this.setuplastupdateddate = value;
    }

    /**
     * Obtient la valeur de la propriété surveylastupdateddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSURVEYLASTUPDATEDDATE() {
        return surveylastupdateddate;
    }

    /**
     * Définit la valeur de la propriété surveylastupdateddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSURVEYLASTUPDATEDDATE(DATETIME value) {
        this.surveylastupdateddate = value;
    }

    /**
     * Obtient la valeur de la propriété valueslastcalculateddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVALUESLASTCALCULATEDDATE() {
        return valueslastcalculateddate;
    }

    /**
     * Définit la valeur de la propriété valueslastcalculateddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVALUESLASTCALCULATEDDATE(DATETIME value) {
        this.valueslastcalculateddate = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/RELIABILITYRANKINGDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for RELIABILITYRANKINGDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RELIABILITYRANKINGDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGLOCKED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGINDEXCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGSCORE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OUTOFSYNC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SETUPLASTUPDATEDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SURVEYLASTUPDATEDDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VALUESLASTCALCULATEDDATE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RELIABILITYRANKINGDETAILS_Type", propOrder = {
    "reliabilityrankinglocked",
    "reliabilityrankingindexcode",
    "reliabilityrankingid",
    "reliabilityrankingscore",
    "outofsync",
    "setuplastupdateddate",
    "surveylastupdateddate",
    "valueslastcalculateddate"
})
public class RELIABILITYRANKINGDETAILS_Type {

    @XmlElement(name = "RELIABILITYRANKINGLOCKED")
    protected String reliabilityrankinglocked;
    @XmlElement(name = "RELIABILITYRANKINGINDEXCODE")
    protected String reliabilityrankingindexcode;
    @XmlElement(name = "RELIABILITYRANKINGID")
    protected RELIABILITYRANKINGID_Type reliabilityrankingid;
    @XmlElement(name = "RELIABILITYRANKINGSCORE")
    protected QUANTITY reliabilityrankingscore;
    @XmlElement(name = "OUTOFSYNC")
    protected String outofsync;
    @XmlElement(name = "SETUPLASTUPDATEDDATE")
    protected DATETIME setuplastupdateddate;
    @XmlElement(name = "SURVEYLASTUPDATEDDATE")
    protected DATETIME surveylastupdateddate;
    @XmlElement(name = "VALUESLASTCALCULATEDDATE")
    protected DATETIME valueslastcalculateddate;

    /**
     * Gets the value of the reliabilityrankinglocked property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRELIABILITYRANKINGLOCKED() {
        return reliabilityrankinglocked;
    }

    /**
     * Sets the value of the reliabilityrankinglocked property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRELIABILITYRANKINGLOCKED(String value) {
        this.reliabilityrankinglocked = value;
    }

    /**
     * Gets the value of the reliabilityrankingindexcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRELIABILITYRANKINGINDEXCODE() {
        return reliabilityrankingindexcode;
    }

    /**
     * Sets the value of the reliabilityrankingindexcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRELIABILITYRANKINGINDEXCODE(String value) {
        this.reliabilityrankingindexcode = value;
    }

    /**
     * Gets the value of the reliabilityrankingid property.
     * 
     * @return
     *     possible object is
     *     {@link RELIABILITYRANKINGID_Type }
     *     
     */
    public RELIABILITYRANKINGID_Type getRELIABILITYRANKINGID() {
        return reliabilityrankingid;
    }

    /**
     * Sets the value of the reliabilityrankingid property.
     * 
     * @param value
     *     allowed object is
     *     {@link RELIABILITYRANKINGID_Type }
     *     
     */
    public void setRELIABILITYRANKINGID(RELIABILITYRANKINGID_Type value) {
        this.reliabilityrankingid = value;
    }

    /**
     * Gets the value of the reliabilityrankingscore property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getRELIABILITYRANKINGSCORE() {
        return reliabilityrankingscore;
    }

    /**
     * Sets the value of the reliabilityrankingscore property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setRELIABILITYRANKINGSCORE(QUANTITY value) {
        this.reliabilityrankingscore = value;
    }

    /**
     * Gets the value of the outofsync property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOUTOFSYNC() {
        return outofsync;
    }

    /**
     * Sets the value of the outofsync property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOUTOFSYNC(String value) {
        this.outofsync = value;
    }

    /**
     * Gets the value of the setuplastupdateddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSETUPLASTUPDATEDDATE() {
        return setuplastupdateddate;
    }

    /**
     * Sets the value of the setuplastupdateddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSETUPLASTUPDATEDDATE(DATETIME value) {
        this.setuplastupdateddate = value;
    }

    /**
     * Gets the value of the surveylastupdateddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSURVEYLASTUPDATEDDATE() {
        return surveylastupdateddate;
    }

    /**
     * Sets the value of the surveylastupdateddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSURVEYLASTUPDATEDDATE(DATETIME value) {
        this.surveylastupdateddate = value;
    }

    /**
     * Gets the value of the valueslastcalculateddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getVALUESLASTCALCULATEDDATE() {
        return valueslastcalculateddate;
    }

    /**
     * Sets the value of the valueslastcalculateddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setVALUESLASTCALCULATEDDATE(DATETIME value) {
        this.valueslastcalculateddate = value;
    }

}
